@@ -4,22 +4,26 @@
 *                                                                              *
 *                               C A L C M O . C                                *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 1996                   *
+*                 Copyright (c) Joerg-R. Hill, December 1997                   *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: calcmo.c,v 1.1 1996/12/10 18:39:57 jrh Exp $
+* $Id: calcmo.c,v 1.2 1998/01/26 00:47:08 jrh Exp jrh $
 * $Log: calcmo.c,v $
+* Revision 1.2  1998/01/26 00:47:08  jrh
+* Release 2.1
+*
 * Revision 1.1  1996/12/10  18:39:57  jrh
 * Initial revision
 *
-*
 */
 #include<math.h>
 #include<stdio.h>
 #include<stdlib.h>
 #include<string.h>
 #include<unistd.h>
+#include<sys/types.h>
+#include<sys/times.h>
 #include<X11/Xlib.h>
 #include<X11/cursorfont.h>
 #include "viewmol.h"
@@ -36,6 +40,7 @@ extern void *getmem(size_t, size_t);
 extern void *expmem(void *, size_t, size_t);
 extern void setCursor(Widget, int);
 extern int norbs(int);
+extern char *bfname(int);
 extern void fremem(void **);
 extern void restoreGeometry(void);
 extern int  messgb(Widget, int, char *, struct PushButtonRow *, int);
@@ -48,7 +53,7 @@ extern struct GRIDOBJECT *gridObjects;
 extern double transx, transy, transz, radfac;
 extern double gridres;
 extern int na, nbasfu, imo, iwavef, ibasfu, ngridobjects;
-extern int needMoloch;
+extern int bfatom, needMoloch;
 extern Widget topShell;
 extern char moloch[];
 
@@ -77,7 +82,8 @@ void calcmo(void)
         if ((iwavef == MOLECULAR_ORBITAL && gridObjects[i].mo == imo) ||
             (iwavef == BASIS_IN_MO && gridObjects[i].mo == imo &&
                                       gridObjects[i].basisfunction == ibasfu) ||
-            (iwavef == BASIS_FUNCTION && gridObjects[i].basisfunction == ibasfu))
+            (iwavef == BASIS_FUNCTION && gridObjects[i].basisfunction == ibasfu) ||
+             iwavef == DENSITY)
         {
 	    if (gridObjects[i].resolution == gridres)
             return;
@@ -304,8 +310,39 @@ int runMoloch(double *grid, double gridres, double box, double step, int imo,
 void setGridObject(struct GRIDOBJECT *gridObject, double gridres, int iwavef,
                    int imo, int ibasfu)
 {
+  char *word;
+
   gridObject->resolution=gridres;
   gridObject->type=iwavef;
   gridObject->mo=imo;
   gridObject->basisfunction=ibasfu;
+  switch (iwavef)
+  {
+    case BASIS_FUNCTION:    word=getStringResource(topShell, "basisfunctionTitle");
+				    sprintf(gridObject->text, word, ibasfu+1,
+				            atoms[bfatom].name, bfatom+1, bfname(ibasfu));
+                            break;
+    case BASIS_IN_MO:       word=getStringResource(topShell, "basisfunctionInMOTitle");
+				    sprintf(gridObject->text, word, ibasfu+1, imo+1,
+						atoms[bfatom].name, bfatom+1,
+						orbitals[imo].coeff[ibasfu], bfname(ibasfu));
+                            break;
+    case MOLECULAR_ORBITAL: word=getStringResource(topShell, "molecularOrbitalTitle");
+				    sprintf(gridObject->text, word, imo+1,
+						orbitals[imo].symmetry, orbitals[imo].energy);
+				    break;
+    case DENSITY:           word=getStringResource(topShell, "electronDensityTitle");
+				    sprintf(gridObject->text, word);
+				    break;
+  }
+}
+
+clock_t getCPUTime(void)
+{
+  struct tms buffer;
+
+  if (times(&buffer) != -1)
+    return(buffer.tms_utime+buffer.tms_stime);
+  else
+    return((clock_t)0);
 }
