@@ -700,6 +700,8 @@ void allocWindowColors(void)
     XtVaGetValues(windows[VIEWER].widget, XmNforeground, &pixel, NULL);
     getRGBColor(windows[VIEWER].widget, pixel, &(windows[VIEWER].foreground_rgb[0]),
                 &(windows[VIEWER].foreground_rgb[1]), &(windows[VIEWER].foreground_rgb[2]));
+    windows[VIEWER].background_rgb[3]=1.0;
+    windows[VIEWER].foreground_rgb[3]=1.0;
   }
   else
   {
