@@ -105,7 +105,7 @@ extern GLfloat light0p[], light1p[];
 extern int na, nb, ne, ninternal, nmodes, ngridobjects;
 extern int label, mode, showForces, animate, existsUnitCell, showUnitCell, showInertia;
 extern int primitive, imo, ibasfu, bfatom, lights, moveItem, projectionMode;
-extern int shadows;
+extern int shadows, ground;
 extern double *cnm, cycle, amplitude, forceScale, wnScale;
 extern double gridres, sphereres, lineWidth;
 extern double tinert[3][3];
@@ -238,7 +238,7 @@ void drawMolecule(Widget w, caddr_t client_data, GLwDrawingAreaCallbackStruct *d
   }
   if (projectionMode == PERSPECTIVE)
   {
-    drawGround();
+    if (ground) drawGround();
     glEnable(GL_CLIP_PLANE0);
   }
   glTranslatef(xmov[MOLECULE], ymov[MOLECULE], zmov[MOLECULE]);
@@ -257,6 +257,7 @@ void drawMolecule(Widget w, caddr_t client_data, GLwDrawingAreaCallbackStruct *d
     glEnable(GL_BLEND);
     glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
     glColor4f(0.0, 0.0, 0.0, 0.5);
+    glPassThrough((GLfloat)(ADD_DEPTH+(int)(2.0*windows[VIEWER].far)));
     glPopMatrix();
     ground0[1]=windows[VIEWER].bottom;
     ground1[1]=windows[VIEWER].bottom;
@@ -270,6 +271,7 @@ void drawMolecule(Widget w, caddr_t client_data, GLwDrawingAreaCallbackStruct *d
     found=renderMolecule((width+height)/2, FALSE);
     glDisable(GL_BLEND);
     glDisable(GL_STENCIL_TEST);
+    glPassThrough((GLfloat)(ADD_DEPTH));
   }
 
   if (label) labelAtoms(LABEL);
@@ -289,7 +291,7 @@ void drawMolecule(Widget w, caddr_t client_data, GLwDrawingAreaCallbackStruct *d
 int renderMolecule(int width, int lighting)
 {
   double boxf;
-  const float black[4] = {0.0, 0.0, 0.0, 0.0};
+  const float black[4] = {0.0, 0.0, 0.0, 1.0};
   int prim=GL_LINE_LOOP;
   register int i, found=0;
 
@@ -318,9 +320,9 @@ int renderMolecule(int width, int lighting)
     stickModel(FALSE, lighting);
   if (windows[VIEWER].mode == STICKMODEL)
   {
-    glPassThrough((GLfloat)(ADD_DEPTH+(int)(windows[VIEWER].far)));
+    if (lighting) glPassThrough((GLfloat)(ADD_DEPTH+(int)(windows[VIEWER].far)));
     balls(-atoms[na].rad, lighting);
-    glPassThrough((GLfloat)(ADD_DEPTH));
+    if (lighting) glPassThrough((GLfloat)(ADD_DEPTH));
   }
   if (windows[VIEWER].mode == BALLMODEL)
     balls(0.5, lighting);
@@ -820,7 +822,7 @@ void drawGround(void)
     glStencilFunc(GL_ALWAYS, 3, 0xffffffff);
     glStencilOp(GL_KEEP, GL_KEEP, GL_REPLACE);
   }
-  glPassThrough((GLfloat)(ADD_DEPTH+(int)(2*windows[VIEWER].far)));
+  glPassThrough((GLfloat)(ADD_DEPTH+(int)(3.0*windows[VIEWER].far)));
   glBegin(GL_POLYGON);
   glVertex3d(10.0*windows[VIEWER].left, windows[VIEWER].bottom, 10.0*windows[VIEWER].near);
   glVertex3d(10.0*windows[VIEWER].left, windows[VIEWER].bottom, 10.0*windows[VIEWER].far);
