@@ -4,16 +4,18 @@
 *                                                                              *
 *                               D R A W O P . C                                *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 1996                   *
+*                 Copyright (c) Joerg-R. Hill, December 1997                   *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: drawop.c,v 1.1 1996/12/10 18:40:36 jrh Exp $
+* $Id: drawop.c,v 1.2 1998/01/26 00:47:34 jrh Exp jrh $
 * $Log: drawop.c,v $
+* Revision 1.2  1998/01/26 00:47:34  jrh
+* Release 2.1
+*
 * Revision 1.1  1996/12/10  18:40:36  jrh
 * Initial revision
 *
-*
 */
 #include<math.h>
 #include<stdio.h>
@@ -34,12 +36,12 @@
 void cross(double, double, double, double);
 
 extern double makeTics(double, double, double *, char *);
-extern void pixwor(Dimension, Dimension, GLdouble, GLdouble, GLdouble, GLdouble, double *, double *);
+extern void pixelToWorld(int, double *, double *);
 extern void drawBackground(int, Pixel, double);
 extern void setWindowColor(int, Pixel, const float *);
 extern int StringWidth(XFontStruct *, char *);
 extern void (*drawBegin)(GLenum), (*drawEnd)(void), (*drawVertex2d)(double, double);
-extern void (*drawString)(char *, double, double, double, GLuint);
+extern void (*drawString)(char *, double, double, double, double, GLuint);
 extern void (*drawLineWidth)(GLfloat);
 extern void printDialog(Widget, caddr_t, XmAnyCallbackStruct *);
 extern char *getStringResource(Widget, char*);
@@ -47,6 +49,7 @@ extern void restoreGeometry(void);
 extern void drawMolecule(Widget, caddr_t, GLwDrawingAreaCallbackStruct *);
 extern void setMenuItem(int, int, int);
 extern void setGeometry(int);
+extern void deleteAnnotation(int *);
 extern void fremem(void **);
 
 extern struct WINDOW windows[];
@@ -57,7 +60,7 @@ extern Pixel stdcol[9], historyColor;
 extern double emax, emin, cycle;
 extern double *coord;
 extern float historyColor_rgb[4];
-extern int na, nhist;
+extern int na, nhist, historyAnnotation;
 extern int swapBuffers;
 
 void drawHistory(Widget w, caddr_t client_data, GLwDrawingAreaCallbackStruct *data)
@@ -67,32 +70,36 @@ void drawHistory(Widget w, caddr_t client_data, GLwDrawingAreaCallbackStruct *da
   double left, right, bottom, top;
   double g, e, xpix, ypix, xpixold, ticMark, ticInc, strl;
   const float black[4] = {0.0, 0.0, 0.0, 0.0};
+  int renderMode;
   register int i;
 
 /* This subroutine draws the diagram for optimization history */
 
-  GLwDrawingAreaMakeCurrent(windows[HISTORY].widget, windows[HISTORY].context);
+  glGetIntegerv(GL_RENDER_MODE, &renderMode);
+  if (renderMode == GL_RENDER)
+    GLwDrawingAreaMakeCurrent(windows[HISTORY].widget, windows[HISTORY].context);
 
   XtVaGetValues(windows[HISTORY].widget, XtNwidth, &width, XtNheight, &height, NULL);
-  e=emax-emin > 0.00001e0 ? emax-emin : 0.00001e0;
+  e=emax-emin > 0.00001 ? emax-emin : 0.00001;
   g=windows[HISTORY].top;
   left=windows[HISTORY].left;
   right=windows[HISTORY].right;
   bottom=windows[HISTORY].bottom;
   top=windows[HISTORY].top;
-  xpixold=0.0e0;
-  xpix=1.0e0;
+  xpixold=0.0;
+  xpix=1.0;
   while (fabs(xpixold-xpix) > 1.0e-4)
   {
     xpixold=xpix;
-    pixwor(width, height, left, right, bottom, top, &xpix, &ypix);
-    left=windows[HISTORY].left-10.0e0*xpix;
-    right=windows[HISTORY].right+10.0e0*xpix;
-    bottom=windows[HISTORY].bottom-10.0e0*ypix;
-    top=windows[HISTORY].top+10.0e0*ypix;
+    xpix=(right-left)/(double)width;
+    ypix=(top-bottom)/(double)height;
+    left=windows[HISTORY].left-10.0*xpix;
+    right=windows[HISTORY].right+10.0*xpix;
+    bottom=windows[HISTORY].bottom-10.0*ypix;
+    top=windows[HISTORY].top+10.0*ypix;
   }
 
-  drawBackground(HISTORY, windows[HISTORY].background, 0.0e0);
+  drawBackground(HISTORY, windows[HISTORY].background, 0.0);
   setWindowColor(FOREGROUND, stdcol[BLACK], black);
   glLoadIdentity();
   glOrtho(left, right, bottom, top, windows[HISTORY].near, windows[HISTORY].far);
@@ -103,39 +110,39 @@ void drawHistory(Widget w, caddr_t client_data, GLwDrawingAreaCallbackStruct *da
   if (windows[HISTORY].mode & SCALES)
   {
     (*drawLineWidth)((GLfloat)1.);
-    ticInc=makeTics(1.e0, (double)nhist, &ticMark, form);
-    if (ticInc < 1.0e0) ticInc=1.0e0;
-    if (ticMark == 1.0e0) ticMark+=ticInc;
+    ticInc=makeTics(1.0, (double)nhist, &ticMark, form);
+    if (ticInc < 1.0) ticInc=1.0;
+    if (ticMark == 1.0) ticMark+=ticInc;
     do
     {
       (*drawBegin)(GL_LINES);
       (*drawVertex2d)(ticMark, g);
-      (*drawVertex2d)(ticMark, g+5.e0*ypix);
+      (*drawVertex2d)(ticMark, g+5.0*ypix);
       (*drawEnd)();
       (*drawBegin)(GL_LINES);
-      (*drawVertex2d)(ticMark, 0.0e0);
-      (*drawVertex2d)(ticMark, -5.e0*ypix);
+      (*drawVertex2d)(ticMark, 0.0);
+      (*drawVertex2d)(ticMark, -5.0*ypix);
       (*drawEnd)();
       sprintf(line, "%d", (int)ticMark);
-      strl=(double)StringWidth(windows[HISTORY].font, line)/2.e0*xpix;
-      (*drawString)(line, ticMark-strl, g-15.e0*ypix, 0.0, windows[HISTORY].GLfontId);
+      strl=(double)StringWidth(windows[HISTORY].font, line)/2.0*xpix;
+      (*drawString)(line, ticMark-strl, g-15.0*ypix, 0.0, 0.0, windows[HISTORY].GLfontId);
       ticMark+=ticInc;
     } while (ticMark < (double)nhist);
 
     if (windows[HISTORY].mode & GNORM)
     {
-	ticInc=makeTics(0.0e0, g, &ticMark, form);
+	ticInc=makeTics(0.0, g, &ticMark, form);
 	ticMark+=ticInc;
       do
       {
         (*drawBegin)(GL_LINES);
         (*drawVertex2d)((double)nhist, ticMark);
-        (*drawVertex2d)((double)nhist+5.e0*xpix, ticMark);
+        (*drawVertex2d)((double)nhist+5.0*xpix, ticMark);
 	  (*drawEnd)();
         sprintf(line, form, ticMark);
         strl=(double)(StringWidth(windows[HISTORY].font, line)+4)*xpix;
         setWindowColor(FOREGROUND, historyColor, historyColor_rgb);
-        (*drawString)(line, (double)nhist-strl, ticMark-5.e0*ypix, 0.0, windows[HISTORY].GLfontId);
+        (*drawString)(line, (double)nhist, ticMark-5.0*ypix, 0.0, (-strl), windows[HISTORY].GLfontId);
         setWindowColor(FOREGROUND, stdcol[BLACK], black);
         ticMark+=ticInc;
       } while (ticMark < g);
@@ -146,12 +153,12 @@ void drawHistory(Widget w, caddr_t client_data, GLwDrawingAreaCallbackStruct *da
       do
       {
         (*drawBegin)(GL_LINES);
-        (*drawVertex2d)(1.e0-5.e0*xpix, (ticMark-emin)*g/e);
-        (*drawVertex2d)(1.e0, (ticMark-emin)*g/e);
+        (*drawVertex2d)(1.0-5.0*xpix, (ticMark-emin)*g/e);
+        (*drawVertex2d)(1.0, (ticMark-emin)*g/e);
 	  (*drawEnd)();
         sprintf(line, form, ticMark);
         setWindowColor(FOREGROUND, windows[HISTORY].foreground, windows[HISTORY].foreground_rgb);
-        (*drawString)(line, 1.e0+3.e0*xpix, (ticMark-emin)*g/e-5.e0*ypix, 0.0, windows[HISTORY].GLfontId);
+        (*drawString)(line, 1.0+3.0*xpix, (ticMark-emin)*g/e-5.0*ypix, 0.0, 0.0, windows[HISTORY].GLfontId);
         setWindowColor(FOREGROUND, stdcol[BLACK], black);
         ticMark+=ticInc;
       } while (ticMark < e+emin);
@@ -162,32 +169,32 @@ void drawHistory(Widget w, caddr_t client_data, GLwDrawingAreaCallbackStruct *da
 
   (*drawLineWidth)((GLfloat)3.);
   (*drawBegin)(GL_LINE_LOOP);
-  (*drawVertex2d)(1.e0, 0.0e0);
-  (*drawVertex2d)(1.e0, g);
+  (*drawVertex2d)(1.0, 0.0);
+  (*drawVertex2d)(1.0, g);
   (*drawVertex2d)((double)nhist, g);
-  (*drawVertex2d)((double)nhist, 0.0e0);
+  (*drawVertex2d)((double)nhist, 0.0);
   (*drawEnd)();
   if (windows[HISTORY].mode & GNORM)
   {
     setWindowColor(FOREGROUND, historyColor, historyColor_rgb);
     (*drawBegin)(GL_LINES);
-    (*drawVertex2d)((double)nhist-150.e0*xpix, g-40.e0*ypix);
-    (*drawVertex2d)((double)nhist-130.e0*xpix, g-40.e0*ypix);
+    (*drawVertex2d)((double)nhist-150.0*xpix, g-40.0*ypix);
+    (*drawVertex2d)((double)nhist-130.0*xpix, g-40.0*ypix);
     (*drawEnd)();
     setWindowColor(FOREGROUND, stdcol[BLACK], black);
     word=getStringResource(topShell, "gradientNorm");
-    (*drawString)(word, (double)nhist-120.e0*xpix, g-40.e0*ypix, 0.0, windows[HISTORY].GLfontId);
+    (*drawString)(word, (double)nhist-120.0*xpix, g-40.0*ypix, 0.0, 0.0, windows[HISTORY].GLfontId);
   }
   if (windows[HISTORY].mode & ENERGY)
   {
     setWindowColor(FOREGROUND, windows[HISTORY].foreground, windows[HISTORY].foreground_rgb);
     (*drawBegin)(GL_LINES);
-    (*drawVertex2d)((double)nhist-150.e0*xpix, g-60.e0*ypix);
-    (*drawVertex2d)((double)nhist-130.e0*xpix, g-60.e0*ypix);
+    (*drawVertex2d)((double)nhist-150.0*xpix, g-60.0*ypix);
+    (*drawVertex2d)((double)nhist-130.0*xpix, g-60.0*ypix);
     (*drawEnd)();
     setWindowColor(FOREGROUND, stdcol[BLACK], black);
     word=getStringResource(topShell, "energy");
-    (*drawString)(word, (double)nhist-120.e0*xpix, g-60.e0*ypix, 0.0, windows[HISTORY].GLfontId);
+    (*drawString)(word, (double)nhist-120.0*xpix, g-60.0*ypix, 0.0, 0.0, windows[HISTORY].GLfontId);
   }
 
 /* Draw gradient norm curve */
@@ -239,8 +246,8 @@ void cross(double cycle, double e, double xpix, double ypix)
     b=optimization[c1-1].gnorm+a*((double)c1-cycle);
     e=windows[HISTORY].top;
   }
-  xpix*=10.e0;
-  ypix*=10.e0;
+  xpix*=10.0;
+  ypix*=10.0;
   (*drawBegin)(GL_LINES);
   (*drawVertex2d)(cycle, b*windows[HISTORY].top/e-ypix);
   (*drawVertex2d)(cycle, b*windows[HISTORY].top/e+ypix);
@@ -257,9 +264,10 @@ void quitHistory(Widget w, caddr_t client_data, XmAnyCallbackStruct *data)
   fremem((void **)&windows[HISTORY].font);
   XtDestroyWidget(XtParent(XtParent(windows[HISTORY].widget)));
   windows[HISTORY].widget=0;
+  deleteAnnotation(&historyAnnotation);
   restoreGeometry();
   drawMolecule((Widget)0, (caddr_t)0, (GLwDrawingAreaCallbackStruct *)0);
-  setMenuItem(VIEWER, 8, True);
+  setMenuItem(VIEWER, 9, True);
 }
 
 void historyKeyAction(KeySym keysym)
