@@ -4,15 +4,17 @@
 *                                                                              *
 *                            F A L L B A C K S . H                             *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 1996                   *
+*                 Copyright (c) Joerg-R. Hill, December 1997                   *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: fallbacks.h,v 1.1 1996/12/10 18:45:31 jrh Exp $
+* $Id: fallbacks.h,v 1.2 1998/01/26 00:47:41 jrh Exp jrh $
 * $Log: fallbacks.h,v $
- * Revision 1.1  1996/12/10  18:45:31  jrh
- * Initial revision
- *
+* Revision 1.2  1998/01/26 00:47:41  jrh
+* Release 2.1
+*
+* Revision 1.1  1996/12/10  18:45:31  jrh
+* Initial revision
 *
 */
 static String fallbacks[] = {
@@ -20,13 +22,21 @@ static String fallbacks[] = {
   "Viewmol.Moloch:                                  moloch",
   "Viewmol.Rayshade:                                rayshade",
   "Viewmol.DisplayRLE:                              xv %s",
-  "Viewmol*geometry:                                500x500+50+50",
+/* the following three resources are necessary to get
+   the Indigo Magic Desktop look-and-feel */
+  "Viewmol*sgiMode:                                 True",
+  "Viewmol*useSchemes:                              all",
+  "Viewmol*SgNuseEnhancedFSB:                       True",
+/* end of SGI specfic stuff */
+  "Viewmol.geometry:                                500x500+50+50",
   "Viewmol.history.geometry:                        500x250+50+590",
   "Viewmol.spectrum.geometry:                       500x250+50+590",
   "Viewmol.MODiagram.geometry:                      250x500+565+50",
   "Viewmol.model:                                   wire",
   "Viewmol.drawingMode:                             surface",
+  "Viewmol.bondType:                                conjugated",
   "Viewmol.sphereResolution:                        10",
+  "Viewmol.lineWidth:                               0",
   "Viewmol.simplifyWhileRotating:                   True",
   "Viewmol.interpolation:                           linear",
   "Viewmol.bondLength:                              %7.4f Ang",
@@ -56,6 +66,7 @@ static String fallbacks[] = {
   "Viewmol.history*font:                            variable",
   "Viewmol.MODiagram*font:                          variable",
   "Viewmol*viewer.canvas.background:                white",
+  "Viewmol*viewer.canvas.foreground:                gray75",
   "Viewmol*spectrum.canvas.background:              white",
   "Viewmol*spectrum.canvas.foreground:              black",
   "Viewmol*history.canvas.background:               white",
@@ -93,6 +104,16 @@ static String fallbacks[] = {
   "Viewmol*clear_last.labelString:                  Clear last",
   "Viewmol*clear_last.accelerator:                  Ctrl<Key>L",
   "Viewmol*clear_last.acceleratorText:              Ctrl+L",
+  "Viewmol*_popup.bondType_menu.labelString:        Bond type ...",
+  "Viewmol*single.labelString:                      single only",
+  "Viewmol*single.accelerator:                      Ctrl<Key>S",
+  "Viewmol*single.acceleratorText:                  Ctrl+S",
+  "Viewmol*multiple.labelString:                    multiple",
+  "Viewmol*multiple.accelerator:                    Ctrl<Key>M",
+  "Viewmol*multiple.acceleratorText:                Ctrl+M",
+  "Viewmol*conjugated.labelString:                  conjugated",
+  "Viewmol*conjugated.accelerator:                  Ctrl<Key>C",
+  "Viewmol*conjugated.acceleratorText:              Ctrl+C",
   "Viewmol*_popup.wave_function.labelString:        Wave function ...",
   "Viewmol*_popup.wave_function.mnemonic:           v",
   "Viewmol*_popup.wave_function.accelerator:        Meta<Key>V",
@@ -120,9 +141,15 @@ static String fallbacks[] = {
   "Viewmol*_popup.background_color.labelString:     Background color ...",
   "Viewmol*_popup.background_color.mnemonic:        B",
   "Viewmol*_popup.background_color.accelerator:     Meta<Key>B",
+  "Viewmol*_popup.foreground_color.labelString:     Ground color ...",
+  "Viewmol*_popup.foreground_color.mnemonic:        G",
+  "Viewmol*_popup.foreground_color.accelerator:     Meta<Key>G",
   "Viewmol*_popup.label_atoms.labelString:          Label atoms",
   "Viewmol*_popup.label_atoms.mnemonic:             L",
   "Viewmol*_popup.label_atoms.accelerator:          Meta<Key>L",
+  "Viewmol*_popup.annotate.labelString:             Annotate",
+  "Viewmol*_popup.annotate.accelerator:             Ctrl<Key>N",
+  "Viewmol*_popup.annotate.acceleratorText:         Ctrl+N",
   "Viewmol*_popup.hardcopy.labelString:             Save drawing",
   "Viewmol*_popup.hardcopy.mnemonic:                d",
   "Viewmol*_popup.hardcopy.accelerator:             Meta<Key>D",
@@ -132,7 +159,8 @@ static String fallbacks[] = {
   "Viewmol*_popup.manual.labelString:               Help/Manual",
   "Viewmol*_popup.manual.mnemonic:                  H",
   "Viewmol*_popup.manual.accelerator:               Meta<Key>H",
-  "Viewmol*_popup.save.labelString:                 Save molecule",
+  "Viewmol*_popup.saveMolecule.labelString:         Save molecule",
+  "Viewmol*_popup.saveConfiguration.labelString:    Save configuration",
   "Viewmol*_popup.quit.labelString:                 Quit",
   "Viewmol*_popup.quit.mnemonic:                    Q",
   "Viewmol*_popup.quit.accelerator:                 Meta<Key>Q",
@@ -140,6 +168,12 @@ static String fallbacks[] = {
   "Viewmol.spectrum*_popup.settings_spectrum.labelString: Settings for spectrum ...",
   "Viewmol.spectrum*_popup.settings_spectrum.mnemonic: S",
   "Viewmol.spectrum*_popup.settings_spectrum.accelerator: Meta<Key>S",
+  "Viewmol.spectrum*_popup.observed_spectrum.labelString: Read observed spectrum ...",
+  "Viewmol.spectrum*_popup.observed_spectrum.mnemonic: R",
+  "Viewmol.spectrum*_popup.observed_spectrum.accelerator: Meta<Key>R",
+  "Viewmol.spectrum*_popup.delete_spectrum.labelString: Delete observed spectrum ...",
+  "Viewmol.spectrum*_popup.delete_spectrum.mnemonic: e",
+  "Viewmol.spectrum*_popup.delete_spectrum.accelerator: Meta<Key>E",
   "Viewmol.spectrum*_popup.imaginary_wave_numbers.labelString: Imaginary wave numbers ...",
   "Viewmol.spectrum*_popup.zoom_out.labelString:    Zoom out",
   "Viewmol.spectrum*_popup.zoom_out.mnemonic:       Z",
@@ -187,7 +221,7 @@ static String fallbacks[] = {
   "Viewmol.MODiagram*_popup.hardcopy.labelString:   Save drawing",
   "Viewmol.MODiagram*_popup.hardcopy.mnemonic:      d",
   "Viewmol.MODiagram*_popup.hardcopy.accelerator:   Meta<Key>D",
-  "Viewmol.MODiagram*_popup.energy_levels.labelString: Draw energy levels",
+  "Viewmol.MODiagram*_popup.energy_levels.labelString: Draw density of states",
   "Viewmol.MODiagram*_popup.energy_levels.mnemonic: e",
   "Viewmol.MODiagram*_popup.energy_levels.accelerator: Meta<Key>E",
   "Viewmol.MODiagram*_popup.foreground_color.labelString: Foreground color ...",
@@ -277,14 +311,26 @@ static String fallbacks[] = {
   "Viewmol*drawingModeForm*surfaces.labelString:    with surface",
   "Viewmol*drawingModeForm*simplify.labelString:    Lines while rotating",
   "Viewmol*drawingModeForm*onOffLabel.labelString:  Lights on/off",
-  "Viewmol*drawingModeForm*light0.labelString:      Light 1",
-  "Viewmol*drawingModeForm*light1.labelString:      Light 2",
-  "Viewmol*drawingModeForm*moveLabel.labelString:   Move light",
-  "Viewmol*drawingModeForm*nomove.labelString:      Do not move light",
+  "Viewmol*drawingModeForm*molecule.labelString:    Move molecule",
+  "Viewmol*drawingModeForm*viewpoint.labelString:   Move view point",
+  "Viewmol*drawingModeForm*light0.labelString:      Move light 1",
+  "Viewmol*drawingModeForm*light1.labelString:      Move light 2",
+  "Viewmol*drawingModeForm*projectionLabel.labelString: Projection",
+  "Viewmol*drawingModeForm*orthographic.labelString: Orthographic",
+  "Viewmol*drawingModeForm*perspective.labelString: Perspective",
+  "Viewmol*drawingModeForm*light0OnOff.labelString: Light 1",
+  "Viewmol*drawingModeForm*light1OnOff.labelString: Light 2",
   "Viewmol*drawingModeForm*sphereResolutionLabel.labelString: Resolution of spheres",
-  "Viewmol*colorEditor_popup.title:                 Color Editor",
+  "Viewmol*drawingModeForm*lineWidthLabel.labelString: Line width",
+  "Viewmol*colorEditor.title:                       Color Editor",
+  "Viewmol*colorEditor*smoothRed.labelString:       Smooth",
+  "Viewmol*colorEditor*smoothGreen.labelString:     Smooth",
+  "Viewmol*colorEditor*smoothBlue.labelString:      Smooth",
   "viewmol*doRaytracing.labelString:                Start raytracing",
   "viewmol*stopRaytracing.labelString:              Don't start raytracing",
+  "Viewmol*saveMoleculeForm_popup*title:            Save molecule",
+  "Viewmol*saveMoleculeForm*mol.labelString:        MDL mol-file",
+  "Viewmol*saveMoleculeForm*tm.labelString:         Turbomole file",
   "Viewmol.unknownParameter:                        Unknown command line parameter: %s",
   "Viewmol.selectFormat:                            Please select format.",
   "Viewmol.selectCompression:                       Please select compression method.",
@@ -293,6 +339,7 @@ static String fallbacks[] = {
   "Viewmol.PostscriptSaved:                         Drawing saved to Postscript file %s.",
   "Viewmol.RaytracerSaved:                          Drawing saved to Rayshade file %s.",
   "Viewmol.MoleculeSaved:                           Molecule saved to file %s.",
+  "Viewmol.ConfigurationSaved:                      Configuration saved to file $HOME/.Xdefaults.",
   "Viewmol.noControlFile:                           There is no control file in the current directory.",
   "Viewmol.unableToOpen:                            Unable to open file %s.",
   "Viewmol.molochFailed:                            Moloch failed.",
@@ -308,10 +355,10 @@ static String fallbacks[] = {
   "Viewmol.noBrowser:                               Cannot find Web browser for the manual.\\n%s does not exist. Put a line\\n'Viewmol.webBrowser: <your Web browser>'\\ninto your $HOME/.Xdefaults file.",
   "Viewmol.noManual:                                Manual file %s\\ndoes not exist.",
   "Viewmol.cannotDisplay:                           Unable to display manual.\nWeb browser does not start.",
-  "Viewmol.tooManyBonds:                            I found more than 8 bonds on atom %d.\\nCheck your coordinates and radii.",
   "Viewmol.noVisual:                                Unable to find a window suitable for OpenGL drawing.\\nThere might be an installation problem with OpenGL\\nor the X server has not been started with the\\ncorrect extensions.",
   "Viewmol.noRayshade:                              No location for Rayshade specified in resources.",
   "Viewmol.noDisplay:                               No display program for RLE files specified in resources.",
+  "Viewmol.unableToWriteFeedback:                   Cannot allocate enough memory to write drawing to file.",
   "Viewmol.wavenumberTitle:                         %s mode, %.6g cm-1",
   "Viewmol.selectAtomTitle:                         Please select atom by clicking on it.",
   "Viewmol.selectINSTitle:                          Click on atom to set INS weight to %f.",
@@ -319,8 +366,8 @@ static String fallbacks[] = {
   "Viewmol.basisfunctionInMOTitle:                  Basis function %d in MO %d: %s%d %.7f*%s",
   "Viewmol.molecularOrbitalTitle:                   Molecular orbital %d: %s, energy %f Hartree",
   "Viewmol.electronDensityTitle:                    Electron density",
-  "Viewmol.isosurfacePlusMinus:                     isosurface: %.3f, %.3f",
-  "Viewmol.isosurfacePlus:                          isosurface: %.3f e",
+  "Viewmol.isosurfaceLabel:                         isosurface: ",
+  "Viewmol.isosurfaceLevel:                         %.3f ",
   "Viewmol.historyTitle:                            Cycle %d Energy %18.10f Hartree, |dE/dxyz| %10.6f",
   "Viewmol.wavenumber:                              Wave numbers (cm**-1)",
   "Viewmol.intensity:                               Intensity (%)",
@@ -333,8 +380,10 @@ static String fallbacks[] = {
   "Viewmol.unknownResource:                         The value %s is not allowed for\\nthe resource %s.",
   "Viewmol.unsupportedVersion:                      Files of version %s are not supported.",
   "Viewmol.wrongFiletype:                           File %s is of wrong file type.",
+  "Viewmol.wrongReference:                          File referenced in %s as 'type=car' is of wrong file type.",
   "Viewmol.unknownErrorMessage:                     Input filter sent unknown error message:\\n%s.",
   "Viewmol.noCoordinates:                           Cannot find coordinates in file %s.",
   "Viewmol.noEnergy:                                Cannot find energy in file %s.",
+  "Viewmol.noMOselected:                            There is no MO selected. Please select a MO\\nin the energy level diagram, then try again.",
   NULL
 };
