@@ -60,7 +60,6 @@ extern void hpglClose(FILE *);
 extern int  messgb(Widget, int, char *, struct PushButtonRow *, int);
 extern int  StringWidth(XFontStruct *, char *);
 extern int  StringHeight(XFontStruct *);
-extern void (*drawString)(char *, double, double, double, double, GLuint);
 extern void setWindowColor(int, Pixel, const float *);
 extern void writeFeedback(FILE *, int, GLfloat *, int, int, int, int);
 
@@ -69,7 +68,7 @@ extern struct WINDOW windows[];
 extern Pixel stdcol[9];
 extern double paperWidth, paperHeight, sphereres;
 extern char title[], *text, *textPointer;
-extern int na, nb, iwavef, shadows;
+extern int na, nb, iwavef, shadows, ground;
 extern int rgbMode, swapBuffers, primitive, debug;
 
 char *saveTiff(int window, char *file, int compression)
@@ -221,7 +220,7 @@ char *saveVectorFile(int window, char *file, int format)
   GLwDrawingAreaMakeCurrent(windows[window].widget, windows[window].context);
   swapBuffers=FALSE;
   shadowsSave=shadows;
-  shadows=FALSE;
+  if (format != POSTSCRIPT) shadows=FALSE;
   strcpy(str, PROGRAM);
   strcat(str, " ");
   strcat(str, VERSION);
@@ -239,6 +238,7 @@ char *saveVectorFile(int window, char *file, int format)
     case HPGL:       f=hpglInit(file, (double)width, (double)height, paperWidth,
                                 paperHeight, fontSizeX/110., fontSizeY/40.,
                                 portrait);
+			   ground=FALSE;
                      break;
     case POSTSCRIPT: if (window == VIEWER && (windows[window].mode != WIREMODEL || iwavef != ALL_OFF)
                          && primitive == GLU_FILL) smooth=TRUE;
@@ -267,6 +267,7 @@ char *saveVectorFile(int window, char *file, int format)
         (void)glRenderMode(GL_FEEDBACK);
         redraw(window);
         setWindowColor(FOREGROUND, stdcol[BLACK], black);
+        glMatrixMode(GL_PROJECTION);
         glLoadIdentity();
         glOrtho(windows[window].left, windows[window].right, windows[window].bottom,
                 windows[window].top, windows[window].near, windows[window].far);
@@ -310,6 +311,7 @@ char *saveVectorFile(int window, char *file, int format)
   {
     case HPGL:       hpglClose(f);
                      word=getStringResource(topShell, "HPGLSaved");
+			   ground=TRUE;
                      break;
     case POSTSCRIPT: PostscriptClose(f);
                      word=getStringResource(topShell, "PostscriptSaved");
