@@ -4,16 +4,18 @@
 *                                                                              *
 *                                I N P U T . C                                 *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 1996                   *
+*                 Copyright (c) Joerg-R. Hill, December 1997                   *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: input.c,v 1.1 1996/12/10 18:41:26 jrh Exp $
+* $Id: input.c,v 1.2 1998/01/26 00:48:07 jrh Exp jrh $
 * $Log: input.c,v $
+* Revision 1.2  1998/01/26 00:48:07  jrh
+* Release 2.1
+*
 * Revision 1.1  1996/12/10  18:41:26  jrh
 * Initial revision
 *
-*
 */
 #include<ctype.h>
 #include<stdlib.h>
@@ -97,7 +99,7 @@ int input(int argc, char **argv)
       readNext=TRUE;
       for (i=0; i<nopt; i++)
       {
-          if (!strcmp(options[i].flag, argv[1]))
+        if (!strncmp(options[i].flag, argv[1], 8))
         {
           sprintf(command, options[i].command, argv[2]);
           readNext=FALSE;
@@ -172,13 +174,13 @@ int input(int argc, char **argv)
 	    if ((word=strtok(NULL, " \t")) != NULL)
 		radfac=atof(word);
           else
-		radfac=1.0e0;
+		radfac=1.0;
 	  }
         else
           radfac=atof(word);
 	}
       else
-        radfac=1.0e0;
+        radfac=1.0;
       bndfac*=radfac;
       while (fgets(line, MAXLENLINE, file) != NULL)
       {
@@ -525,17 +527,23 @@ int input(int argc, char **argv)
       while (fgets(line, MAXLENLINE, file) != NULL)
       {
         if (strchr(line, '$')) break;
+        w=strrchr(line, '\\');
         word=strtok(line, " \t");
         word=strtok(NULL, " \t");
         help=(int *)getmem(mna, sizeof(int));
         i=getNumber(word, help);
-        fgets(line, MAXLENLINE, file);
-        while (strstr(line, "basis") == NULL && !strchr(line, '$'))
+        while (w != NULL)
+        {
           fgets(line, MAXLENLINE, file);
-        word=strtok(line, "=");
-        word=strtok(NULL, "\\\n");
-        for (j=0; j<i; j++)
-          strncpy(atoms[help[j]-1].basisname, word, MAXLENBASISNAME-1);
+          w=strrchr(line, '\\');
+          if (strstr(line, "basis") != NULL)
+          {
+            word=strtok(line, "=");
+            word=strtok(NULL, "\\\n");
+            for (j=0; j<i; j++)
+              strncpy(atoms[help[j]-1].basisname, word, MAXLENBASISNAME-1);
+          }
+        }
         fremem((void **)&help);
       }
       readNext=FALSE;
