@@ -4,16 +4,18 @@
 *                                                                              *
 *                            P R I N T F O R M . C                             *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 1996                   *
+*                 Copyright (c) Joerg-R. Hill, December 1997                   *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: printform.c,v 1.1 1996/12/10 18:43:19 jrh Exp $
+* $Id: printform.c,v 1.2 1998/01/26 00:49:05 jrh Exp jrh $
 * $Log: printform.c,v $
+* Revision 1.2  1998/01/26 00:49:05  jrh
+* Release 2.1
+*
 * Revision 1.1  1996/12/10  18:43:19  jrh
 * Initial revision
 *
-*
 */
 #include<stdlib.h>
 #include<X11/Intrinsic.h>
@@ -46,7 +48,7 @@ void GetCompression(Widget, caddr_t, XmToggleButtonCallbackStruct *);
 void SetPapersize(int);
 void Fileselect(Widget, caddr_t, XmAnyCallbackStruct *);
 
-extern void GetInsWeight(Widget, caddr_t, XmAnyCallbackStruct *);
+extern void GetDouble(Widget, caddr_t, XmAnyCallbackStruct *);
 extern Widget makeMenu(Widget, int, char *, struct MenuItem *);
 extern void MapBox(Widget, caddr_t, XmAnyCallbackStruct *);
 extern Widget CreateToggleBox(Widget, struct PushButtonRow *, int, int,
@@ -116,8 +118,8 @@ void printDialog(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
   landscape_save=landscape;
   window=(int)which;
 
-  setMenuItem(VIEWER, 18, False);
-  if (windows[SPECTRUM].widget) setMenuItem(SPECTRUM, 3, False);
+  setMenuItem(VIEWER, 21, False);
+  if (windows[SPECTRUM].widget) setMenuItem(SPECTRUM, 5, False);
   if (windows[HISTORY].widget) setMenuItem(HISTORY, 1, False);
   if (windows[MO].widget) setMenuItem(MO, 3, False);
   XtSetArg(args[0], XmNautoUnmanage, False);
@@ -149,8 +151,7 @@ void printDialog(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
                             XmVERTICAL, 1, True, format-2);
   if (window != VIEWER || (windows[VIEWER].mode == WIREMODEL && iwavef == ALL_OFF))
      XtVaSetValues(radiobox1_buttons[RAYTRACER-2].widget, XmNsensitive, False, NULL);
-  if ((animate == ANIMATE && mode != (-1) && window == VIEWER) ||
-	(imo != (-1) && window == MO))
+  if ((animate == ANIMATE && mode != (-1) && window == VIEWER))
   {
     XtVaSetValues(radiobox1_buttons[HPGL-2].widget, XmNsensitive, False, NULL);
     XtVaSetValues(radiobox1_buttons[POSTSCRIPT-2].widget, XmNsensitive, False, NULL);
@@ -159,7 +160,7 @@ void printDialog(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
      (iwavef != ALL_OFF || windows[window].mode != WIREMODEL))
   {
     XtVaSetValues(radiobox1_buttons[HPGL-2].widget, XmNsensitive, False, NULL);
-    XtVaSetValues(radiobox1_buttons[POSTSCRIPT-2].widget, XmNsensitive, False, NULL);
+/*  XtVaSetValues(radiobox1_buttons[POSTSCRIPT-2].widget, XmNsensitive, False, NULL);*/
   }
   XtVaSetValues(radiobox1, XmNleftAttachment, XmATTACH_FORM,
                            XmNtopAttachment, XmATTACH_FORM,
@@ -244,7 +245,7 @@ void printDialog(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
                      break;
     case HPGL:       strcpy(name, "vm_plot.hpgl");
                      break;
-    case POSTSCRIPT: strcpy(name, "vm_plot.ps");
+    case POSTSCRIPT: strcpy(name, "vm_plot.eps");
                      break;
     case RAYTRACER:  strcpy(name, "vm_image.ray");
                      break;
@@ -312,7 +313,7 @@ void printDialog(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
                                  XmNrightAttachment, XmATTACH_FORM,
                                  XmNbottomAttachment, XmATTACH_FORM,
                                  NULL);
-  XtAddCallback(pWidth, XmNvalueChangedCallback, (XtCallbackProc)GetInsWeight, &paperWidth);
+  XtAddCallback(pWidth, XmNvalueChangedCallback, (XtCallbackProc)GetDouble, &paperWidth);
 
   sprintf(line, "%7.2f", paperHeight);
   pHeight=XtVaCreateManagedWidget("height", xmTextWidgetClass, form6,
@@ -322,7 +323,7 @@ void printDialog(Widget widget, caddr_t which, XmAnyCallbackStruct *data)
 					    XmNrightAttachment, XmATTACH_FORM,
                                   XmNbottomAttachment, XmATTACH_FORM,
                                   NULL);
-  XtAddCallback(pHeight, XmNvalueChangedCallback, (XtCallbackProc)GetInsWeight, &paperHeight);
+  XtAddCallback(pHeight, XmNvalueChangedCallback, (XtCallbackProc)GetDouble, &paperHeight);
 
   if (paper != USER)
   {
@@ -368,7 +369,7 @@ void GetFormat(Widget button, caddr_t which, XmToggleButtonCallbackStruct *data)
                      XtVaSetValues(comp, XmNsensitive, False, NULL);
                      XtVaSetValues(paperformat, XmNsensitive, True, NULL);
                      break;
-    case POSTSCRIPT: strcpy(name, "vm_plot.ps");
+    case POSTSCRIPT: strcpy(name, "vm_plot.eps");
                      XtVaSetValues(radiobox2_buttons[0].widget, XmNsensitive, True, NULL);
                      XtVaSetValues(radiobox2_buttons[1].widget, XmNsensitive, True, NULL);
                      XtVaSetValues(comp, XmNsensitive, False, NULL);
@@ -445,7 +446,7 @@ void printDialogExit(Widget button, caddr_t which, XmPushButtonCallbackStruct *d
   static struct PushButtonRow buttons[] = {{"continue", GetMessageBoxButton, (XtPointer)0, NULL}};
   char *file, *dot, *word=NULL;
   char f[MAXLENLINE], num[3], str[MAXLENLINE];
-  register int i, n;
+  register int i, j, n;
 
   if (!(int)which)
   {
@@ -462,22 +463,24 @@ void printDialogExit(Widget button, caddr_t which, XmPushButtonCallbackStruct *d
 				 dot=strrchr(file, '.');
 				 n=dot-file;
 				 setAnimation(FALSE);
-				 for (i=0; i<24; i++)
+				 j=1;
+				 for (i=0; i<20; i++)
 				 {
 				   strncpy(f, file, n);
 				   f[n]='\0';
 				   sprintf(num, "%2.2d", i);
 				   strcat(f, num);
 				   strcat(f, dot);
-				   normalMode((XtPointer)0);
+				   normalMode((XtPointer)j);
 				   word=saveTiff(window, f, compression);
+				   j=0;
 				 }
 				 setAnimation(TRUE);
 				 strncpy(f, file, n);
 				 f[n]='\0';
 				 strcat(f, "XX");
 				 strcat(f, dot);
-				 strcat(f, " (XX=0-23)");
+				 strcat(f, " (XX=0-19)");
 				 file=f;
 			     }
 			     else
@@ -491,22 +494,24 @@ void printDialogExit(Widget button, caddr_t which, XmPushButtonCallbackStruct *d
 				 dot=strrchr(file, '.');
 				 n=dot-file;
 				 setAnimation(FALSE);
-				 for (i=0; i<24; i++)
+				 j=1;
+				 for (i=0; i<20; i++)
 				 {
 				   strncpy(f, file, n);
 				   f[n]='\0';
 				   sprintf(num, "%2.2d", i);
 				   strcat(f, num);
 				   strcat(f, dot);
-				   normalMode((XtPointer)0);
+				   normalMode((XtPointer)j);
 				   word=saveVectorFile(window, f, format);
+				   j=0;
 				 }
 				 setAnimation(TRUE);
 				 strncpy(f, file, n);
 				 f[n]='\0';
 				 strcat(f, "XX");
 				 strcat(f, dot);
-				 strcat(f, " (XX=0-23)");
+				 strcat(f, " (XX=0-19)");
 				 file=f;
 			     }
 			     else
@@ -522,8 +527,8 @@ void printDialogExit(Widget button, caddr_t which, XmPushButtonCallbackStruct *d
   }
   XtDestroyWidget(dialog);
   XtUnmanageChild(fileBox);
-  setMenuItem(VIEWER, 18, True);
-  if (windows[SPECTRUM].widget) setMenuItem(SPECTRUM, 3, True);
+  setMenuItem(VIEWER, 21, True);
+  if (windows[SPECTRUM].widget) setMenuItem(SPECTRUM, 5, True);
   if (windows[HISTORY].widget) setMenuItem(HISTORY, 1, True);
   if (windows[MO].widget) setMenuItem(MO, 3, True);
 }
