@@ -4,16 +4,18 @@
 *                                                                              *
 *                             S P E C F O R M . C                              *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 1996                   *
+*                 Copyright (c) Joerg-R. Hill, December 1997                   *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: specform.c,v 1.1 1996/12/10 18:44:01 jrh Exp $
+* $Id: specform.c,v 1.2 1998/01/26 00:49:33 jrh Exp jrh $
 * $Log: specform.c,v $
+* Revision 1.2  1998/01/26 00:49:33  jrh
+* Release 2.1
+*
 * Revision 1.1  1996/12/10  18:44:01  jrh
 * Initial revision
 *
-*
 */
 #include<stdlib.h>
 #include<X11/Intrinsic.h>
@@ -49,6 +51,7 @@ void GetScale(Widget, caddr_t, XmScrollBarCallbackStruct *);
 void spectrumDialogExit(Widget, caddr_t, XmPushButtonCallbackStruct *);
 void GetIns(Widget, caddr_t, XmToggleButtonCallbackStruct *);
 void GetInsWeight(Widget, caddr_t, XmToggleButtonCallbackStruct *);
+void GetDouble(Widget, caddr_t, XmToggleButtonCallbackStruct *);
 
 extern void MapBox(Widget, caddr_t, XmAnyCallbackStruct *);
 extern Widget CreateToggleBox(Widget, struct PushButtonRow *, int, int,
@@ -63,12 +66,16 @@ extern void restoreGeometry(void);
 extern void distortGeometry(double);
 extern void redraw(int);
 extern void setMenuItem(int, int, int);
+extern int  makeAnnotation(int, int, float, float, int, const GLfloat *, int, char *);
+extern void deleteAnnotation(int *);
 
 extern struct WINDOW windows[];
 extern struct NORMAL_MODE *normal_modes;
 extern int animate, lines, setins, mode;
+extern int setinsAnnotation;
 extern double weight, temp, amplitude, wnScale;
 extern Widget topShell;
+extern Pixel stdcol[9];
 
 static Widget dialog, insweight;
 static int mode_save, animate_save, lines_save, setins_save;
@@ -106,6 +113,8 @@ void spectrumDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
 
   /* This function creates the dialog for the spectrum window */
  
+  setMenuItem(SPECTRUM, 0, False);
+
   mode_save=windows[SPECTRUM].mode;
   animate_save=animate;
   lines_save=lines;
@@ -209,7 +218,7 @@ void spectrumDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
                                   NULL);
   tempSlider.number=&temp;
   tempSlider.decimals=0;
-  tempSlider.draw=(void *)drawSpectrum;
+  tempSlider.draw=(void (*)())drawSpectrum;
   XtAddCallback(slider1, XmNvalueChangedCallback, (XtCallbackProc)GetSlider, &tempSlider);
   XtAddCallback(slider1, XmNdragCallback, (XtCallbackProc)GetSlider, &tempSlider);
 
@@ -280,7 +289,8 @@ void spectrumDialog(Widget widget, caddr_t dummy, XmAnyCallbackStruct *data)
                                     XmNrightAttachment, XmATTACH_FORM,
                                     XmNbottomAttachment, XmATTACH_FORM,
                                     NULL);
-  XtAddCallback(insweight, XmNvalueChangedCallback, (XtCallbackProc)GetInsWeight, &weight);
+  XtAddCallback(insweight, XmNvalueChangedCallback, (XtCallbackProc)GetInsWeight,
+		    NULL);
   if (!setins) XtVaSetValues(insweight, XmNsensitive, False, NULL);
 
   sep5=XtVaCreateManagedWidget("sep5", xmSeparatorWidgetClass, form,
@@ -354,7 +364,7 @@ void GetType(Widget button, caddr_t which, XmToggleButtonCallbackStruct *data)
 
 void GetAmplitude(Widget button, caddr_t dummy, XmScrollBarCallbackStruct *data)
 {
-  amplitude=(double)(data->value)*windows[VIEWER].top/100.e0;
+  amplitude=(double)(data->value)*windows[VIEWER].top/100.0;
   restoreGeometry();
   if (animate == DISTORT) distortGeometry(amplitude);
   drawMolecule((Widget)0, (caddr_t)0, (GLwDrawingAreaCallbackStruct *)0);
@@ -369,19 +379,41 @@ void GetScale(Widget button, caddr_t dest, XmScrollBarCallbackStruct *data)
 
 void GetIns(Widget button, caddr_t dest, XmToggleButtonCallbackStruct *data)
 {
+  const GLfloat black[4] = {0.0, 0.0, 0.0, 0.0};
+  char line[MAXLENLINE], *word;
+
   if (data->set)
   {
     *(int *)dest=TRUE;
     XtVaSetValues(insweight, XmNsensitive, True,  NULL);
+    word=getStringResource(topShell, "selectINSTitle");
+    sprintf(line, word, weight);
+    setinsAnnotation=makeAnnotation(setinsAnnotation, CENTERED, 0.0, 1.0,
+						stdcol[BLACK], black, 0, line);
   }
   else
   {
     *(int *)dest=FALSE;
     XtVaSetValues(insweight, XmNsensitive, False, NULL);
+    deleteAnnotation(&setinsAnnotation);
   }
+  redraw(VIEWER);
 }
 
-void GetInsWeight(Widget button, caddr_t dest, XmToggleButtonCallbackStruct *data)
+void GetInsWeight(Widget button, caddr_t dummy, XmToggleButtonCallbackStruct *data)
+{
+  const GLfloat black[4] = {0.0, 0.0, 0.0, 0.0};
+  char line[MAXLENLINE], *word;
+
+  GetDouble(button, (caddr_t)&weight, data);
+  word=getStringResource(topShell, "selectINSTitle");
+  sprintf(line, word, weight);
+  setinsAnnotation=makeAnnotation(setinsAnnotation, CENTERED, 0.0, 1.0,
+                                  stdcol[BLACK], black, 0, line);
+  redraw(VIEWER);
+}
+
+void GetDouble(Widget button, caddr_t dest, XmToggleButtonCallbackStruct *data)
 {
   char *str;
 
@@ -403,12 +435,14 @@ void spectrumDialogExit(Widget button, caddr_t which, XmPushButtonCallbackStruct
     temp=temp_save;
     amplitude=amplitude_save;
     wnScale=wnScale_save;
+    deleteAnnotation(&setinsAnnotation);
     restoreGeometry();
     sprintf(t, "title%.1d", windows[SPECTRUM].mode);
     string=getStringResource(XtParent(XtParent(windows[SPECTRUM].widget)), t);
     setWindowTitle(XtParent(windows[SPECTRUM].widget), string);
   }
   XtDestroyWidget(dialog);
+  setMenuItem(SPECTRUM, 0, True);
   redraw(SPECTRUM);
   redraw(VIEWER);
 }
