@@ -4,15 +4,17 @@
 *                                                                              *
 *                              V I E W M O L . H                               *
 *                                                                              *
-*                 Copyright (c) Joerg-R. Hill, December 1996                   *
+*                 Copyright (c) Joerg-R. Hill, December 1997                   *
 *                                                                              *
 ********************************************************************************
 *
-* $Id: viewmol.h,v 1.1 1996/12/10 18:46:03 jrh Exp $
+* $Id: viewmol.h,v 1.2 1998/01/26 00:49:43 jrh Exp jrh $
 * $Log: viewmol.h,v $
- * Revision 1.1  1996/12/10  18:46:03  jrh
- * Initial revision
- *
+* Revision 1.2  1998/01/26 00:49:43  jrh
+* Release 2.1
+*
+* Revision 1.1  1996/12/10  18:46:03  jrh
+* Initial revision
 *
 */
 #include<X11/Intrinsic.h>
@@ -20,7 +22,7 @@
 #include<GL/glx.h>
 
 #define PROGRAM "Viewmol"
-#define VERSION "2.0"
+#define VERSION "2.1"
 
 #define MAXLENLINE 132
 #define MAXLENBASISNAME 12
@@ -102,6 +104,33 @@
 #define LEGAL      5
 #define USER       6
 
+#define ORTHO       0
+#define PERSPECTIVE 1
+
+#define LINE_STIPPLE 0x10000
+#define LINE_WIDTH   0x20000
+#define ADD_DEPTH    0x30000
+#define VISIBILITY   0x40000
+
+#define MOLECULE  0
+#define VIEWPOINT 1
+#define LIGHTNO0  2
+#define LIGHTNO1  3
+
+#define CENTERED 1
+#define COORDINATES 2
+
+#define SINGLE_BONDS   1
+#define MULTIPLE_BONDS 2
+#define CONJUGATION    3
+
+#define NOTHING 0
+#define TEXT    1
+#define DELETE  2
+
+#define EDITABLE 0x1
+#define MOVEABLE 0x2
+
 #define LMAX 4        /* maximum l quantum number supported */
 
 struct BASISSET
@@ -119,37 +148,24 @@ struct ATOM
   double z;
   double rad;
   double mass;
-  double neutron_scatterfac;
+  double neutronScatterfac;
   int    nbonds;
+  int    nelectrons;
   struct ELEMENT  *element;
   struct BASISSET *basis;
   char   name[8];
   char   basisname[MAXLENBASISNAME];
 }; 
 
-struct BONDORDER
-{
-  int n;
-  double x1;
-  double y1;
-  double z1;
-  double x2;
-  double y2;
-  double z2;
-  double x3;
-  double y3;
-  double z3;
-  double x4;
-  double y4;
-  double z4;
-};
-
 struct BOND
 {
   int    first;
   int    second;
-  struct BONDORDER *order;
+  int    order;
   double frac;
+  double x;
+  double y;
+  double z;
 };
 
 struct ELEMENT
@@ -185,6 +201,7 @@ struct WINDOW
   GLXContext  context;
   int         foreground;
   int         background;
+  int         smooth;
   int         mode;
   Widget      menu;
   double      left;
@@ -245,6 +262,7 @@ struct GRIDOBJECT
   int    type;
   int    mo;
   int    basisfunction;
+  char   text[MAXLENLINE];
 };
 
 struct ZOOM
@@ -269,3 +287,13 @@ struct SLIDER
   int    decimals;
   void   (*draw)();
 };
+
+struct ANNOTATION
+{
+  double x;
+  double y;
+  float  color_rgb[4];
+  int    color;
+  int    flags;
+  char   text[MAXLENLINE];
+};
